==> eff-monix_3-7.0.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"monix","t":"monix","d":"","k":"static","x":""},
{"l":"org/atnos/eff.html#","e":false,"i":"","n":"org.atnos.eff","t":"org.atnos.eff","d":"","k":"package","x":""},
{"l":"org/atnos/eff/addon/monix.html#","e":false,"i":"","n":"org.atnos.eff.addon.monix","t":"org.atnos.eff.addon.monix","d":"","k":"package","x":""},
{"l":"org/atnos/eff/addon/monix/EffToTask.html#","e":false,"i":"","n":"EffToTask","t":"EffToTask[R]","d":"org.atnos.eff.addon.monix","k":"trait","x":""},
{"l":"org/atnos/eff/addon/monix/EffToTask.html#apply-112","e":false,"i":"","n":"apply","t":"apply[A](e: Eff[R, A]): Task[A]","d":"org.atnos.eff.addon.monix.EffToTask","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#","e":false,"i":"","n":"TaskCreation","t":"TaskCreation extends TaskTypes","d":"org.atnos.eff.addon.monix","k":"trait","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#asyncBoundary-fffffbd1","e":false,"i":"","n":"asyncBoundary","t":"asyncBoundary[R : _task]: Eff[R, Unit]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#asyncBoundary-fffffd01","e":false,"i":"","n":"asyncBoundary","t":"asyncBoundary[R : _task](s: Scheduler): Eff[R, Unit]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#fromTask-2b3","e":false,"i":"","n":"fromTask","t":"fromTask[R : _task, A](task: Task[A], timeout: Option[FiniteDuration]): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#retryUntil-b70","e":false,"i":"","n":"retryUntil","t":"retryUntil[R : _task, A](e: Eff[R, A], condition: A => Boolean, durations: List[FiniteDuration]): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#taskAsync-7c6","e":false,"i":"","n":"taskAsync","t":"taskAsync[R : _task, A](callbackConsumer: (Either[Throwable, A] => Unit) => Unit, timeout: Option[FiniteDuration]): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#taskDelay-fffffd67","e":false,"i":"","n":"taskDelay","t":"taskDelay[R : _task, A](call: => A, timeout: Option[FiniteDuration]): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#taskFailed-ae8","e":false,"i":"","n":"taskFailed","t":"taskFailed[R : _task, A](t: Throwable): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#taskFork-2b3","e":false,"i":"","n":"taskFork","t":"taskFork[R : _task, A](call: Task[A], timeout: Option[FiniteDuration]): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#taskForkScheduler-445","e":false,"i":"","n":"taskForkScheduler","t":"taskForkScheduler[R : _task, A](call: Task[A], scheduler: Scheduler, timeout: Option[FiniteDuration]): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#taskSuspend-fffffd67","e":false,"i":"","n":"taskSuspend","t":"taskSuspend[R : _task, A](task: => Task[Eff[R, A]], timeout: Option[FiniteDuration]): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#waitFor-ffffff83","e":false,"i":"","n":"waitFor","t":"waitFor[R : _task](duration: FiniteDuration): Eff[R, Unit]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation$.html#","e":false,"i":"","n":"TaskCreation","t":"TaskCreation extends TaskCreation","d":"org.atnos.eff.addon.monix","k":"object","x":""},
{"l":"org/atnos/eff/addon/monix/TaskEffect.html#","e":false,"i":"","n":"TaskEffect","t":"TaskEffect extends TaskInterpretation, TaskCreation","d":"org.atnos.eff.addon.monix","k":"trait","x":""},
{"l":"org/atnos/eff/addon/monix/TaskEffect.html#asyncInstance-3fb","e":false,"i":"","n":"asyncInstance","t":"asyncInstance[R : _Task](implicit evidence$12: _Task[R], runEff: EffToTask[R]): Async[[_] =>> Eff[R, _$10]]","d":"org.atnos.eff.addon.monix.TaskEffect","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskEffect.html#effectInstance-fffffcfa","e":false,"i":"","n":"effectInstance","t":"effectInstance[R : _Task](implicit evidence$13: _Task[R], runEff: EffToTask[R], scheduler: Scheduler): Effect[[_] =>> Eff[R, _$12]]","d":"org.atnos.eff.addon.monix.TaskEffect","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskEffect$.html#","e":false,"i":"","n":"TaskEffect","t":"TaskEffect extends TaskEffect","d":"org.atnos.eff.addon.monix","k":"object","x":""},
{"l":"org/atnos/eff/addon/monix/TaskInterpretation.html#","e":false,"i":"","n":"TaskInterpretation","t":"TaskInterpretation extends TaskTypes","d":"org.atnos.eff.addon.monix","k":"trait","x":""},
{"l":"org/atnos/eff/addon/monix/TaskInterpretation.html#forkTasks-467","e":false,"i":"","n":"forkTasks","t":"forkTasks[R, A](e: Eff[R, A])(implicit task: MemberInOut[Task, R]): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskInterpretation.html#memoize-7dc","e":false,"i":"","n":"memoize","t":"memoize[A](key: AnyRef, cache: Cache, task: Task[A]): Task[A]","d":"org.atnos.eff.addon.monix.TaskInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskInterpretation.html#runAsync-9d7","e":false,"i":"","n":"runAsync","t":"runAsync[R, A](e: Eff[R, A])(implicit m: Aux[Task, R, NoFx]): Task[A]","d":"org.atnos.eff.addon.monix.TaskInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskInterpretation.html#runSequential-9d7","e":false,"i":"","n":"runSequential","t":"runSequential[R, A](e: Eff[R, A])(implicit m: Aux[Task, R, NoFx]): Task[A]","d":"org.atnos.eff.addon.monix.TaskInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskInterpretation.html#taskAttempt-467","e":false,"i":"","n":"taskAttempt","t":"taskAttempt[R, A](e: Eff[R, A])(implicit task: MemberInOut[Task, R]): Eff[R, Either[Throwable, A]]","d":"org.atnos.eff.addon.monix.TaskInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskInterpretation.html#taskMemo-13e","e":false,"i":"","n":"taskMemo","t":"taskMemo[R, A](key: AnyRef, cache: Cache, e: Eff[R, A])(implicit task: MemberInOut[Task, R]): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskInterpretation.html#taskSequenceCached-0","e":false,"i":"","n":"taskSequenceCached","t":"taskSequenceCached: SequenceCached[Task]","d":"org.atnos.eff.addon.monix.TaskInterpretation","k":"val","x":""},
{"l":"org/atnos/eff/addon/monix/TaskInterpretation$.html#","e":false,"i":"","n":"TaskInterpretation","t":"TaskInterpretation extends TaskInterpretation","d":"org.atnos.eff.addon.monix","k":"object","x":""},
{"l":"org/atnos/eff/addon/monix/TaskTypes.html#","e":false,"i":"","n":"TaskTypes","t":"TaskTypes","d":"org.atnos.eff.addon.monix","k":"trait","x":""},
{"l":"org/atnos/eff/addon/monix/TaskTypes.html#_Task-0","e":false,"i":"","n":"_Task","t":"_Task[R] = Member[Task, R]","d":"org.atnos.eff.addon.monix.TaskTypes","k":"type","x":""},
{"l":"org/atnos/eff/addon/monix/TaskTypes.html#_task-0","e":false,"i":"","n":"_task","t":"_task[R] = MemberIn[Task, R]","d":"org.atnos.eff.addon.monix.TaskTypes","k":"type","x":""},
{"l":"org/atnos/eff/addon/monix/task$.html#","e":false,"i":"","n":"task","t":"task extends TaskEffect","d":"org.atnos.eff.addon.monix","k":"object","x":""},
{"l":"org/atnos/eff/syntax/addon/monix.html#","e":false,"i":"","n":"org.atnos.eff.syntax.addon.monix","t":"org.atnos.eff.syntax.addon.monix","d":"","k":"package","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/TaskOps.html#","e":false,"i":"","n":"TaskOps","t":"TaskOps[R, A](e: Eff[R, A]) extends AnyVal","d":"org.atnos.eff.syntax.addon.monix","k":"class","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/TaskOps.html#asyncBoundary-122","e":false,"i":"","n":"asyncBoundary","t":"asyncBoundary(implicit task: MemberIn[Task, R]): Eff[R, A]","d":"org.atnos.eff.syntax.addon.monix.TaskOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/TaskOps.html#asyncBoundary-fffff4d0","e":false,"i":"","n":"asyncBoundary","t":"asyncBoundary(s: Scheduler)(implicit task: MemberIn[Task, R]): Eff[R, A]","d":"org.atnos.eff.syntax.addon.monix.TaskOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/TaskOps.html#retryUntil-861","e":false,"i":"","n":"retryUntil","t":"retryUntil(condition: A => Boolean, durations: List[FiniteDuration])(implicit task: MemberIn[Task, R]): Eff[R, A]","d":"org.atnos.eff.syntax.addon.monix.TaskOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/TaskOps.html#runAsync-fffff508","e":false,"i":"","n":"runAsync","t":"runAsync(implicit m: Aux[Task, R, NoFx]): Task[A]","d":"org.atnos.eff.syntax.addon.monix.TaskOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/TaskOps.html#runSequential-fffff508","e":false,"i":"","n":"runSequential","t":"runSequential(implicit m: Aux[Task, R, NoFx]): Task[A]","d":"org.atnos.eff.syntax.addon.monix.TaskOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/TaskOps.html#taskAttempt-16","e":false,"i":"","n":"taskAttempt","t":"taskAttempt(implicit task: MemberInOut[Task, R]): Eff[R, Either[Throwable, A]]","d":"org.atnos.eff.syntax.addon.monix.TaskOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/TaskOps.html#taskMemo-f03","e":false,"i":"","n":"taskMemo","t":"taskMemo(key: AnyRef, cache: Cache)(implicit task: MemberInOut[Task, R]): Eff[R, A]","d":"org.atnos.eff.syntax.addon.monix.TaskOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/task.html#","e":false,"i":"","n":"task","t":"task","d":"org.atnos.eff.syntax.addon.monix","k":"trait","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/task.html#toTaskOps-a12","e":false,"i":"","n":"toTaskOps","t":"toTaskOps[R, A](e: Eff[R, A]): TaskOps[R, A]","d":"org.atnos.eff.syntax.addon.monix.task","k":"def","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/task$.html#","e":false,"i":"","n":"task","t":"task extends task","d":"org.atnos.eff.syntax.addon.monix","k":"object","x":""}];

==> eff-monix_3-7.0.6-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"monix","t":"monix","d":"","k":"static","x":""},
{"l":"org/atnos/eff.html#","e":false,"i":"","n":"org.atnos.eff","t":"org.atnos.eff","d":"","k":"package","x":""},
{"l":"org/atnos/eff/addon/monix.html#","e":false,"i":"","n":"org.atnos.eff.addon.monix","t":"org.atnos.eff.addon.monix","d":"","k":"package","x":""},
{"l":"org/atnos/eff/addon/monix/EffToTask.html#","e":false,"i":"","n":"EffToTask","t":"EffToTask[R]","d":"org.atnos.eff.addon.monix","k":"trait","x":""},
{"l":"org/atnos/eff/addon/monix/EffToTask.html#apply-112","e":false,"i":"","n":"apply","t":"apply[A](e: Eff[R, A]): Task[A]","d":"org.atnos.eff.addon.monix.EffToTask","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#","e":false,"i":"","n":"TaskCreation","t":"TaskCreation extends TaskTypes","d":"org.atnos.eff.addon.monix","k":"trait","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#asyncBoundary-fffffbd1","e":false,"i":"","n":"asyncBoundary","t":"asyncBoundary[R : _task]: Eff[R, Unit]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#asyncBoundary-fffffd01","e":false,"i":"","n":"asyncBoundary","t":"asyncBoundary[R : _task](s: Scheduler): Eff[R, Unit]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#fromTask-2b3","e":false,"i":"","n":"fromTask","t":"fromTask[R : _task, A](task: Task[A], timeout: Option[FiniteDuration]): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#retryUntil-b70","e":false,"i":"","n":"retryUntil","t":"retryUntil[R : _task, A](e: Eff[R, A], condition: A => Boolean, durations: List[FiniteDuration]): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#taskAsync-7c6","e":false,"i":"","n":"taskAsync","t":"taskAsync[R : _task, A](callbackConsumer: ((Either[Throwable, A]) => Unit) => Unit, timeout: Option[FiniteDuration]): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#taskDelay-fffffd67","e":false,"i":"","n":"taskDelay","t":"taskDelay[R : _task, A](call: => A, timeout: Option[FiniteDuration]): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#taskFailed-ae8","e":false,"i":"","n":"taskFailed","t":"taskFailed[R : _task, A](t: Throwable): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#taskFork-2b3","e":false,"i":"","n":"taskFork","t":"taskFork[R : _task, A](call: Task[A], timeout: Option[FiniteDuration]): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#taskForkScheduler-445","e":false,"i":"","n":"taskForkScheduler","t":"taskForkScheduler[R : _task, A](call: Task[A], scheduler: Scheduler, timeout: Option[FiniteDuration]): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#taskSuspend-fffffd67","e":false,"i":"","n":"taskSuspend","t":"taskSuspend[R : _task, A](task: => Task[Eff[R, A]], timeout: Option[FiniteDuration]): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation.html#waitFor-ffffff83","e":false,"i":"","n":"waitFor","t":"waitFor[R : _task](duration: FiniteDuration): Eff[R, Unit]","d":"org.atnos.eff.addon.monix.TaskCreation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskCreation$.html#","e":false,"i":"","n":"TaskCreation","t":"TaskCreation extends TaskCreation","d":"org.atnos.eff.addon.monix","k":"object","x":""},
{"l":"org/atnos/eff/addon/monix/TaskEffect.html#","e":false,"i":"","n":"TaskEffect","t":"TaskEffect extends TaskInterpretation, TaskCreation","d":"org.atnos.eff.addon.monix","k":"trait","x":""},
{"l":"org/atnos/eff/addon/monix/TaskEffect.html#asyncInstance-3fb","e":false,"i":"","n":"asyncInstance","t":"asyncInstance[R : _Task](implicit evidence$1: _Task[R], runEff: EffToTask[R]): Async[[_] =>> Eff[R, _$10]]","d":"org.atnos.eff.addon.monix.TaskEffect","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskEffect.html#effectInstance-fffffcfa","e":false,"i":"","n":"effectInstance","t":"effectInstance[R : _Task](implicit evidence$1: _Task[R], runEff: EffToTask[R], scheduler: Scheduler): Effect[[_] =>> Eff[R, _$13]]","d":"org.atnos.eff.addon.monix.TaskEffect","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskEffect$.html#","e":false,"i":"","n":"TaskEffect","t":"TaskEffect extends TaskEffect","d":"org.atnos.eff.addon.monix","k":"object","x":""},
{"l":"org/atnos/eff/addon/monix/TaskInterpretation.html#","e":false,"i":"","n":"TaskInterpretation","t":"TaskInterpretation extends TaskTypes","d":"org.atnos.eff.addon.monix","k":"trait","x":""},
{"l":"org/atnos/eff/addon/monix/TaskInterpretation.html#forkTasks-467","e":false,"i":"","n":"forkTasks","t":"forkTasks[R, A](e: Eff[R, A])(implicit task: MemberInOut[Task, R]): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskInterpretation.html#memoize-7dc","e":false,"i":"","n":"memoize","t":"memoize[A](key: AnyRef, cache: Cache, task: Task[A]): Task[A]","d":"org.atnos.eff.addon.monix.TaskInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskInterpretation.html#runAsync-9d7","e":false,"i":"","n":"runAsync","t":"runAsync[R, A](e: Eff[R, A])(implicit m: Aux[Task, R, NoFx]): Task[A]","d":"org.atnos.eff.addon.monix.TaskInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskInterpretation.html#runSequential-9d7","e":false,"i":"","n":"runSequential","t":"runSequential[R, A](e: Eff[R, A])(implicit m: Aux[Task, R, NoFx]): Task[A]","d":"org.atnos.eff.addon.monix.TaskInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskInterpretation.html#taskAttempt-467","e":false,"i":"","n":"taskAttempt","t":"taskAttempt[R, A](e: Eff[R, A])(implicit task: MemberInOut[Task, R]): Eff[R, Either[Throwable, A]]","d":"org.atnos.eff.addon.monix.TaskInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskInterpretation.html#taskMemo-13e","e":false,"i":"","n":"taskMemo","t":"taskMemo[R, A](key: AnyRef, cache: Cache, e: Eff[R, A])(implicit task: MemberInOut[Task, R]): Eff[R, A]","d":"org.atnos.eff.addon.monix.TaskInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/addon/monix/TaskInterpretation.html#taskSequenceCached-0","e":false,"i":"","n":"taskSequenceCached","t":"taskSequenceCached: SequenceCached[Task]","d":"org.atnos.eff.addon.monix.TaskInterpretation","k":"val","x":""},
{"l":"org/atnos/eff/addon/monix/TaskInterpretation$.html#","e":false,"i":"","n":"TaskInterpretation","t":"TaskInterpretation extends TaskInterpretation","d":"org.atnos.eff.addon.monix","k":"object","x":""},
{"l":"org/atnos/eff/addon/monix/TaskTypes.html#","e":false,"i":"","n":"TaskTypes","t":"TaskTypes","d":"org.atnos.eff.addon.monix","k":"trait","x":""},
{"l":"org/atnos/eff/addon/monix/TaskTypes.html#_Task-0","e":false,"i":"","n":"_Task","t":"_Task[R] = Member[Task, R]","d":"org.atnos.eff.addon.monix.TaskTypes","k":"type","x":""},
{"l":"org/atnos/eff/addon/monix/TaskTypes.html#_task-0","e":false,"i":"","n":"_task","t":"_task[R] = MemberIn[Task, R]","d":"org.atnos.eff.addon.monix.TaskTypes","k":"type","x":""},
{"l":"org/atnos/eff/addon/monix/task$.html#","e":false,"i":"","n":"task","t":"task extends TaskEffect","d":"org.atnos.eff.addon.monix","k":"object","x":""},
{"l":"org/atnos/eff/syntax/addon/monix.html#","e":false,"i":"","n":"org.atnos.eff.syntax.addon.monix","t":"org.atnos.eff.syntax.addon.monix","d":"","k":"package","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/TaskOps.html#","e":false,"i":"","n":"TaskOps","t":"TaskOps[R, A](e: Eff[R, A]) extends AnyVal","d":"org.atnos.eff.syntax.addon.monix","k":"class","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/TaskOps.html#asyncBoundary-122","e":false,"i":"","n":"asyncBoundary","t":"asyncBoundary(implicit task: MemberIn[Task, R]): Eff[R, A]","d":"org.atnos.eff.syntax.addon.monix.TaskOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/TaskOps.html#asyncBoundary-fffff4d0","e":false,"i":"","n":"asyncBoundary","t":"asyncBoundary(s: Scheduler)(implicit task: MemberIn[Task, R]): Eff[R, A]","d":"org.atnos.eff.syntax.addon.monix.TaskOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/TaskOps.html#retryUntil-861","e":false,"i":"","n":"retryUntil","t":"retryUntil(condition: A => Boolean, durations: List[FiniteDuration])(implicit task: MemberIn[Task, R]): Eff[R, A]","d":"org.atnos.eff.syntax.addon.monix.TaskOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/TaskOps.html#runAsync-fffff508","e":false,"i":"","n":"runAsync","t":"runAsync(implicit m: Aux[Task, R, NoFx]): Task[A]","d":"org.atnos.eff.syntax.addon.monix.TaskOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/TaskOps.html#runSequential-fffff508","e":false,"i":"","n":"runSequential","t":"runSequential(implicit m: Aux[Task, R, NoFx]): Task[A]","d":"org.atnos.eff.syntax.addon.monix.TaskOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/TaskOps.html#taskAttempt-16","e":false,"i":"","n":"taskAttempt","t":"taskAttempt(implicit task: MemberInOut[Task, R]): Eff[R, Either[Throwable, A]]","d":"org.atnos.eff.syntax.addon.monix.TaskOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/TaskOps.html#taskMemo-f03","e":false,"i":"","n":"taskMemo","t":"taskMemo(key: AnyRef, cache: Cache)(implicit task: MemberInOut[Task, R]): Eff[R, A]","d":"org.atnos.eff.syntax.addon.monix.TaskOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/task.html#","e":false,"i":"","n":"task","t":"task","d":"org.atnos.eff.syntax.addon.monix","k":"trait","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/task.html#toTaskOps-a12","e":false,"i":"","n":"toTaskOps","t":"toTaskOps[R, A](e: Eff[R, A]): TaskOps[R, A]","d":"org.atnos.eff.syntax.addon.monix.task","k":"def","x":""},
{"l":"org/atnos/eff/syntax/addon/monix/task$.html#","e":false,"i":"","n":"task","t":"task extends task","d":"org.atnos.eff.syntax.addon.monix","k":"object","x":""}];
